@@ -33,7 +33,6 @@
 #include "edgeseqobject.h"
 #include "error.h"
 #include "graphobject.h"
-#include "py2compat.h"
 #include "random.h"
 #include "vertexobject.h"
 #include "vertexseqobject.h"
@@ -130,7 +129,6 @@ static struct module_state _state = { 0, 0 };
 
 #define GETSTATE(m) (&_state)
 
-#ifdef IGRAPH_PYTHON3
 static int igraphmodule_traverse(PyObject *m, visitproc visit, void* arg) {
   Py_VISIT(GETSTATE(m)->progress_handler);
   Py_VISIT(GETSTATE(m)->status_handler);
@@ -142,7 +140,6 @@ static int igraphmodule_clear(PyObject *m) {
   Py_CLEAR(GETSTATE(m)->status_handler);
   return 0;
 }
-#endif
 
 static int igraphmodule_igraph_interrupt_hook(void* data) {
   if (PyErr_CheckSignals()) {
@@ -433,7 +430,7 @@ PyObject* igraphmodule_is_degree_sequence(PyObject *self,
     return NULL;
   }
 
-  if (igraph_is_degree_sequence(&out_deg, is_directed ? &in_deg : 0, &result)) {
+  if (igraph_is_graphical(&out_deg, is_directed ? &in_deg : 0, IGRAPH_LOOPS_SW | IGRAPH_MULTI_SW, &result)) {
     igraphmodule_handle_igraph_error();
     igraph_vector_destroy(&out_deg);
     if (is_directed)
@@ -473,7 +470,7 @@ PyObject* igraphmodule_is_graphical_degree_sequence(PyObject *self,
     return NULL;
   }
 
-  if (igraph_is_graphical_degree_sequence(&out_deg, is_directed ? &in_deg : 0, &result)) {
+  if (igraph_is_graphical(&out_deg, is_directed ? &in_deg : 0, IGRAPH_SIMPLE_SW, &result)) {
     igraphmodule_handle_igraph_error();
     igraph_vector_destroy(&out_deg);
     if (is_directed)
@@ -606,19 +603,19 @@ static PyMethodDef igraphmodule_methods[] =
 {
   {"community_to_membership", (PyCFunction)igraphmodule_community_to_membership,
     METH_VARARGS | METH_KEYWORDS,
-    "community_to_membership(merges, nodes, steps, return_csize=False)"
+    "community_to_membership(merges, nodes, steps, return_csize=False)\n--\n\n"
   },
   {"_compare_communities", (PyCFunction)igraphmodule_compare_communities,
     METH_VARARGS | METH_KEYWORDS,
-    "_compare_communities(comm1, comm2, method=\"vi\")"
+    "_compare_communities(comm1, comm2, method=\"vi\")\n--\n\n"
   },
   {"_power_law_fit", (PyCFunction)igraphmodule_power_law_fit,
     METH_VARARGS | METH_KEYWORDS,
-    "_power_law_fit(data, xmin=-1, force_continuous=False)"
+    "_power_law_fit(data, xmin=-1, force_continuous=False)\n--\n\n"
   },
   {"convex_hull", (PyCFunction)igraphmodule_convex_hull,
     METH_VARARGS | METH_KEYWORDS,
-    "convex_hull(vs, coords=False)\n\n"
+    "convex_hull(vs, coords=False)\n--\n\n"
     "Calculates the convex hull of a given point set.\n\n"
     "@param vs: the point set as a list of lists\n"
     "@param coords: if C{True}, the function returns the\n"
@@ -630,7 +627,7 @@ static PyMethodDef igraphmodule_methods[] =
   },
   {"is_degree_sequence", (PyCFunction)igraphmodule_is_degree_sequence,
     METH_VARARGS | METH_KEYWORDS,
-    "is_degree_sequence(out_deg, in_deg=None)\n\n"
+    "is_degree_sequence(out_deg, in_deg=None)\n--\n\n"
     "Deprecated since 0.9 in favour of L{is_graphical()}.\n\n"
     "Returns whether a list of degrees can be a degree sequence of some graph.\n\n"
     "Note that it is not required for the graph to be simple; in other words,\n"
@@ -650,7 +647,7 @@ static PyMethodDef igraphmodule_methods[] =
   },
   {"is_graphical", (PyCFunction)igraphmodule_is_graphical,
     METH_VARARGS | METH_KEYWORDS,
-    "is_graphical(out_deg, in_deg=None, loops=False, multiple=False)\n\n"
+    "is_graphical(out_deg, in_deg=None, loops=False, multiple=False)\n--\n\n"
     "Returns whether a list of degrees can be a degree sequence of some graph,\n"
     "with or without multiple and loop edges, depending on the allowed edge types\n"
     "in the remaining arguments.\n\n"
@@ -665,7 +662,7 @@ static PyMethodDef igraphmodule_methods[] =
   },
   {"is_graphical_degree_sequence", (PyCFunction)igraphmodule_is_graphical_degree_sequence,
     METH_VARARGS | METH_KEYWORDS,
-    "is_graphical_degree_sequence(out_deg, in_deg=None)\n\n"
+    "is_graphical_degree_sequence(out_deg, in_deg=None)\n--\n\n"
     "Deprecated since 0.9 in favour of L{is_graphical()}.\n\n"
     "Returns whether a list of degrees can be a degree sequence of some simple graph.\n\n"
     "Note that it is required for the graph to be simple; in other words,\n"
@@ -679,7 +676,7 @@ static PyMethodDef igraphmodule_methods[] =
     "  degree sequence, C{False} otherwise.\n"
   },
   {"set_progress_handler", igraphmodule_set_progress_handler, METH_O,
-      "set_progress_handler(handler)\n\n"
+      "set_progress_handler(handler)\n--\n\n"
       "Sets the handler to be called when igraph is performing a long operation.\n"
       "@param handler: the progress handler function. It must accept two\n"
       "  arguments, the first is the message informing the user about\n"
@@ -687,7 +684,7 @@ static PyMethodDef igraphmodule_methods[] =
       "  progress information (a percentage).\n"
   },
   {"set_random_number_generator", igraph_rng_Python_set_generator, METH_O,
-      "set_random_number_generator(generator)\n\n"
+      "set_random_number_generator(generator)\n--\n\n"
       "Sets the random number generator used by igraph.\n"
       "@param generator: the generator to be used. It must be a Python object\n"
       "  with at least three attributes: C{random}, C{randint} and C{gauss}.\n"
@@ -701,7 +698,7 @@ static PyMethodDef igraphmodule_methods[] =
       "  for random numbers, but you cannot set its seed or save its state.\n"
   },
   {"set_status_handler", igraphmodule_set_status_handler, METH_O,
-      "set_status_handler(handler)\n\n"
+      "set_status_handler(handler)\n--\n\n"
       "Sets the handler to be called when igraph tries to display a status\n"
       "message.\n\n"
       "This is used to communicate the progress of some calculations where\n"
@@ -713,33 +710,30 @@ static PyMethodDef igraphmodule_methods[] =
   },
   {"_split_join_distance", (PyCFunction)igraphmodule_split_join_distance,
     METH_VARARGS | METH_KEYWORDS,
-    "_split_join_distance(comm1, comm2)"
+    "_split_join_distance(comm1, comm2)\n--\n\n"
   },
   {"_disjoint_union", (PyCFunction)igraphmodule__disjoint_union,
     METH_VARARGS | METH_KEYWORDS,
-    "_disjoint_union(graphs)"
+    "_disjoint_union(graphs)\n--\n\n"
   },
   {"_union", (PyCFunction)igraphmodule__union,
     METH_VARARGS | METH_KEYWORDS,
-    "_union(graphs, edgemaps)"
+    "_union(graphs, edgemaps)\n--\n\n"
   },
   {"_intersection", (PyCFunction)igraphmodule__intersection,
     METH_VARARGS | METH_KEYWORDS,
-    "_intersection(graphs, edgemaps)"
+    "_intersection(graphs, edgemaps)\n--\n\n"
   },
   {NULL, NULL, 0, NULL}
 };
 
 #define MODULE_DOCS \
   "Low-level Python interface for the igraph library. " \
-  "Should not be used directly.\n\n"                    \
-  "@undocumented: community_to_membership, _compare_communities, _power_law_fit, " \
-  "_split_join_distance, _union, _intersection, _disjoint_union"
+  "Should not be used directly.\n"
 
 /**
- * Module definition table (only for Python 3.x)
+ * Module definition table
  */
-#ifdef IGRAPH_PYTHON3
 static struct PyModuleDef moduledef = {
   PyModuleDef_HEAD_INIT,
   "igraph._igraph",                   /* m_name */
@@ -751,7 +745,6 @@ static struct PyModuleDef moduledef = {
   igraphmodule_clear,                 /* m_clear */
   0                                   /* m_free */
 };
-#endif
 
 /****************** Exported API functions *******************/
 
@@ -798,16 +791,8 @@ igraph_t* PyIGraph_ToCGraph(PyObject* graph) {
 extern PyObject* igraphmodule_InternalError;
 extern PyObject* igraphmodule_arpack_options_default;
 
-#ifdef IGRAPH_PYTHON3
-#  define INITERROR return NULL
-   PyObject* PyInit__igraph(void)
-#else
-#  define INITERROR return
-#  ifndef PyMODINIT_FUNC
-#    define PyMODINIT_FUNC void
-#  endif
-   PyMODINIT_FUNC init_igraph(void)
-#endif
+#define INITERROR return NULL
+PyObject* PyInit__igraph(void)
 {
   PyObject* m;
   static void *PyIGraph_API[PyIGraph_API_pointers];
@@ -847,12 +832,7 @@ extern PyObject* igraphmodule_arpack_options_default;
     INITERROR;
 
   /* Initialize the core module */
-#ifdef IGRAPH_PYTHON3
   m = PyModule_Create(&moduledef);
-#else
-  m = Py_InitModule3("igraph._igraph", igraphmodule_methods, MODULE_DOCS);
-#endif
-
   if (m == NULL)
     INITERROR;
 
@@ -947,18 +927,12 @@ extern PyObject* igraphmodule_arpack_options_default;
   PyIGraph_API[PyIGraph_ToCGraph_NUM]   = (void *)PyIGraph_ToCGraph;
 
   /* Create a CObject containing the API pointer array's address */
-#ifdef IGRAPH_PYTHON3
   c_api_object = PyCapsule_New((void*)PyIGraph_API, "igraph._igraph._C_API", 0);
-#else
-  c_api_object = PyCObject_FromVoidPtr((void*)PyIGraph_API, 0);
-#endif
   if (c_api_object != 0) {
     PyModule_AddObject(m, "_C_API", c_api_object);
   }
 
   igraphmodule_initialized = 1;
 
-#ifdef IGRAPH_PYTHON3
   return m;
-#endif
 }
