@@ -1,11 +1,21 @@
 import unittest
-from igraph import *
+
+from igraph import Graph, InternalError
+
 
 try:
     import numpy as np
-    import pandas as pd
 except ImportError:
     np = None
+
+try:
+    import scipy.sparse as sparse
+except ImportError:
+    sparse = None
+
+try:
+    import pandas as pd
+except ImportError:
     pd = None
 
 
@@ -125,17 +135,72 @@ class GeneratorTests(unittest.TestCase):
         self.assertTrue(g1.isomorphic(g2))
         self.assertRaises(InternalError, Graph.LCF, 12, (5, -5), -3)
 
+    def testRealizeDegreeSequence(self):
+        # Test case insensitivity of options too
+        g = Graph.Realize_Degree_Sequence(
+            [1, 1], None, "simPLE", "smallest",
+        )
+        self.assertFalse(g.is_directed())
+        self.assertTrue(g.degree() == [1, 1])
+
+        # Not implemented, should fail
+        self.assertRaises(
+            NotImplementedError, Graph.Realize_Degree_Sequence,
+            [1, 1], None, "loops", "largest"
+        )
+
+        g = Graph.Realize_Degree_Sequence(
+            [1, 1], None, "all", "largest",
+        )
+        self.assertFalse(g.is_directed())
+        self.assertTrue(g.degree() == [1, 1])
+
+        g = Graph.Realize_Degree_Sequence(
+            [1, 1], None, "multi", "index",
+        )
+        self.assertFalse(g.is_directed())
+        self.assertTrue(g.degree() == [1, 1])
+
+        g = Graph.Realize_Degree_Sequence(
+            [1, 1], [1, 1], "simple", "largest",
+        )
+        self.assertTrue(g.is_directed())
+        self.assertTrue(g.indegree() == [1, 1])
+        self.assertTrue(g.outdegree() == [1, 1])
+
+        # Not implemented, should fail
+        self.assertRaises(
+            NotImplementedError, Graph.Realize_Degree_Sequence,
+            [1, 1], [1, 1], "multi", "largest"
+        )
+
+        self.assertRaises(
+            ValueError, Graph.Realize_Degree_Sequence,
+            [1, 1], [1, 1], "should_fail", "index"
+        )
+        self.assertRaises(
+            ValueError, Graph.Realize_Degree_Sequence,
+            [1, 1], [1, 1], "multi", "should_fail"
+        )
+
+        # Degree sequence of Zachary karate club, using optional arguments
+        zachary = Graph.Famous("zachary")
+        degrees = zachary.degree()
+        g = Graph.Realize_Degree_Sequence(degrees)
+        self.assertFalse(g.is_directed())
+        self.assertTrue(g.degree() == degrees)
+
     def testKautz(self):
         g = Graph.Kautz(2, 2)
-        deg_in = g.degree(mode=IN)
-        deg_out = g.degree(mode=OUT)
+        deg_in = g.degree(mode="in")
+        deg_out = g.degree(mode="out")
         # This is not a proper test, but should spot most errors
         self.assertTrue(g.is_directed() and deg_in == [2] * 12 and deg_out == [2] * 12)
 
     def testDeBruijn(self):
         g = Graph.De_Bruijn(2, 3)
-        deg_in = g.degree(mode=IN, loops=True)
-        deg_out = g.degree(mode=OUT, loops=True)
+        deg_in = g.degree(mode="in", loops=True)
+        deg_out = g.degree(mode="out", loops=True)
         # This is not a proper test, but should spot most errors
         self.assertTrue(g.is_directed() and deg_in == [2] * 8 and deg_out == [2] * 8)
 
@@ -169,6 +234,56 @@ class GeneratorTests(unittest.TestCase):
         pref_matrix[0][1] = 0.7
         self.assertRaises(InternalError, Graph.SBM, 60, pref_matrix, types)
 
+    @unittest.skipIf(np is None, "test case depends on NumPy")
+    def testAdjacencyNumPy(self):
+        mat = np.array(
+            [[0, 1, 1, 0], [1, 0, 0, 0], [0, 0, 2, 0], [0, 1, 0, 0]],
+        )
+
+        # ADJ_DIRECTED (default)
+        g = Graph.Adjacency(mat)
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (2, 2), (2, 2), (3, 1)])
+
+        # ADJ MIN
+        g = Graph.Adjacency(mat, mode="min")
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (2, 2), (2, 2)])
+
+        # ADJ LOWER
+        g = Graph.Adjacency(mat, mode="lower")
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (2, 2), (2, 2), (1, 3)])
+
+    @unittest.skipIf(
+        (sparse is None) or (np is None), "test case depends on NumPy/SciPy"
+    )
+    def testSparseAdjacency(self):
+        mat = sparse.coo_matrix(
+            [[0, 1, 1, 0], [1, 0, 0, 0], [0, 0, 2, 0], [0, 1, 0, 0]],
+        )
+
+        # ADJ_DIRECTED (default)
+        g = Graph.Adjacency(mat)
+        el = g.get_edgelist()
+        self.assertTrue(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (2, 2), (2, 2), (3, 1)])
+
+        # ADJ MIN
+        g = Graph.Adjacency(mat, mode="min")
+        el = g.get_edgelist()
+        self.assertFalse(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (2, 2), (2, 2)])
+
+        # ADJ LOWER
+        g = Graph.Adjacency(mat, mode="lower")
+        el = g.get_edgelist()
+        self.assertFalse(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (2, 2), (2, 2), (1, 3)])
+
     def testWeightedAdjacency(self):
         mat = [[0, 1, 2, 0], [2, 0, 0, 0], [0, 0, 2.5, 0], [0, 1, 0, 0]]
 
@@ -187,6 +302,63 @@ class GeneratorTests(unittest.TestCase):
         self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (3, 1)])
         self.assertTrue(g.es["w0"] == [1, 2, 2, 1])
 
+    @unittest.skipIf(np is None, "test case depends on NumPy")
+    def testWeightedAdjacencyNumPy(self):
+        mat = np.array(
+            [[0, 1, 2, 0], [2, 0, 0, 0], [0, 0, 2.5, 0], [0, 1, 0, 0]],
+        )
+
+        g = Graph.Weighted_Adjacency(mat, attr="w0")
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (2, 2), (3, 1)])
+        self.assertTrue(g.es["w0"] == [1, 2, 2, 2.5, 1])
+
+        g = Graph.Weighted_Adjacency(mat, mode="plus")
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 3), (2, 2)])
+        self.assertTrue(g.es["weight"] == [3, 2, 1, 2.5])
+
+        g = Graph.Weighted_Adjacency(mat, attr="w0", loops=False)
+        el = g.get_edgelist()
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (3, 1)])
+        self.assertTrue(g.es["w0"] == [1, 2, 2, 1])
+
+    @unittest.skipIf(
+        (sparse is None) or (np is None), "test case depends on NumPy/SciPy"
+    )
+    def testSparseWeighedAdjacency(self):
+        mat = sparse.coo_matrix(
+            [[0, 1, 2, 0], [2, 0, 0, 0], [0, 0, 2.5, 0], [0, 1, 0, 0]]
+        )
+
+        g = Graph.Weighted_Adjacency(mat, attr="w0")
+        el = g.get_edgelist()
+        self.assertTrue(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (2, 2), (3, 1)])
+        self.assertTrue(g.es["w0"] == [1, 2, 2, 2.5, 1])
+
+        g = Graph.Weighted_Adjacency(mat, mode="plus")
+        el = g.get_edgelist()
+        self.assertFalse(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (0, 2), (2, 2), (1, 3)])
+        self.assertTrue(g.es["weight"] == [3, 2, 2.5, 1])
+
+        g = Graph.Weighted_Adjacency(mat, mode="min")
+        el = g.get_edgelist()
+        self.assertFalse(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (2, 2)])
+        self.assertTrue(g.es["weight"] == [1, 2.5])
+
+        g = Graph.Weighted_Adjacency(mat, attr="w0", loops=False)
+        el = g.get_edgelist()
+        self.assertTrue(g.is_directed())
+        self.assertEqual(4, g.vcount())
+        self.assertTrue(el == [(0, 1), (0, 2), (1, 0), (3, 1)])
+        self.assertTrue(g.es["w0"] == [1, 2, 2, 1])
+
     @unittest.skipIf((np is None) or (pd is None), "test case depends on NumPy/Pandas")
     def testDataFrame(self):
         edges = pd.DataFrame(
